#!/bin/sh
# @(#)07	1.7 src/pdweb/webseald/junctions/remote/query_contents/query_contents.sh, pdweb.ws.junctions.remote, amweb600, 110201a 12/20/10 23:57:11
#
# FILENAME
#	query_contents
#
# DESCRIPTION
#	Lists the contents of a directory.  Used by the wand server to
#	determine the contents of a third-party Web server to which it
#	is junctioned.
#
#	This script should be installed on the third-party Web server
#	with URL /cgi-bin/query_contents
#
# HISTORY
# $Log: query_contents.sh,v $
# Revision 1.1.2.1  1998/10/19  20:08:51  amurdoch
# 	Moved from src/wand/intraverse/wand to src/wand/intraverse/query_contents
#
# Revision 1.1.1.2  1998/10/19  17:24:34  amurdoch
# 	Moved from src/wand/intraverse/wand to src/wand/intraverse/query_contents
#
# $EndLog$

#
# procduceDocument()
#
#	Write a document to stdout.  Reads the document body from stdin
#
#	$1 - Document type (html or plain)
#	$2 - Document title (html only).
#
produceDocument()
{
    TYPE=$1
    TITLE=$2
    case $TYPE in
    html)
	echo "CONTENT-TYPE: text/html"
	echo
	echo "<HTML>"
	echo "<HEAD>"
	echo "<TITLE> $TITLE </TITLE>"
	echo "</HEAD>"
	echo "<BODY>"
	cat
	echo "</BODY>"
	echo "</HTML>"
	;;
    plain)
	echo "CONTENT-TYPE: text/plain"
	echo
	cat
	;;
    esac
}

#
# Constants
#
STATUS_OK=100
STATUS_ARGS=101
STATUS_NO_EXIST=102
STATUS_NOT_DIR=103


(

# * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * #
#									#
#          Set a value for iconv to use for the local codeset.		#
#    As shipped this script assumes the local codeset is ISO8859-1.	#
#    If this is not correct for your locale then please check your	#
#  operating system documentation to determine the correct name to use	#
#      for your locale and modify the following line accordingly.	#
#									#
# * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * #
ICONV_LANG=ISO8859-1

#
# Set the document root directory.  Below are default directories for
# a number of server types
#
# NOTE: change this section so that the document root is set correctly
# for your installation.
# 
#
ADD_TO_ROOT=
# Set DOCROOTDIR to the document root of your Web server.
DOCROOTDIR=/usr/local/html
# If your cgi-bin directory is not located below your document root on your 
# filesystem, you will need to uncoment the ADD_TO_ROOT line below
#ADD_TO_ROOT="cgi-bin//"

#
# Check the script parameters in command line arguments else extract from environment variable QUERY_STRING
#
# IZ37098 - Start
# Added the ability to Check the script parameters in command line arguments
#

if [ $1 ] ; then
    QUERY_STRING=$1
fi
# IZ37098 - End

#
# Extract script parameters from environment variable QUERY_STRING
#
OPERATION=`echo $QUERY_STRING | sed -e "s;=.*;;"`
OBJPATH=`echo $QUERY_STRING | sed -e "s;.*=;;"`

#
# uri-decode and translate from UTF-8 to LCS and back only if WebSEAL says 
# it uri-encoded
#
if [ "$HTTP_X_QUERY_CONTENTS_URIENCODED" = "yes" ]
then
    OBJPATH=`echo $OBJPATH | perl -pe 'tr/+/ /;s/%?([0-9a-fA-F][0-9a-fA-F])/pack("C", hex($1))/eg;' | sed -e "s;^/;;"|iconv -f UTF-8 -t $ICONV_LANG`
else
    OBJPATH=`echo $OBJPATH | sed -e "s;^/;;"`
fi

FULLOBJPATH=$DOCROOTDIR/$OBJPATH


#
# The following servers don't have cgi-bin under document root by default
#
# NOTE: Change this to set the full path to the requested object (FULLOBJPATH)
# for your installation.
#
case "$SERVER_SOFTWARE" in
Apache*)
    case "$OBJPATH" in
    cgi-bin|cgi-bin/*)
	TMPOBJPATH=`echo $OBJPATH | sed -e "s;^cgi-bin;;" -e "s;^/;;"`
	FULLOBJPATH=$DOCROOTDIR/../cgi-bin/$TMPOBJPATH
	;;
    esac
    ;;
esac


#
# Perform requested operation.  If FULLOBJPATH is set corrently, there is
# no need to change this section
#
case $OPERATION in
dirlist)
    if [ ! -d "$FULLOBJPATH" ]
    then
	echo $STATUS_NOT_DIR
    else
	echo $STATUS_OK
	(
	if [ -z "$OBJPATH" ]
	then
	    for FILE in $ADD_TO_ROOT
	    do
		echo $FILE
	    done
	fi
	OLDIFS=$IFS
	IFS='
'
	for FILE in `ls "$FULLOBJPATH"`
	do
	    if [ -d "$FULLOBJPATH/$FILE" ]
	    then
		echo ${FILE}//
	    else
		echo $FILE
	    fi
	done
	IFS=$OLDIFS
	) | sort | uniq | (
	    if [ "$HTTP_X_QUERY_CONTENTS_URIENCODED" = "yes" ]
	    then
    		iconv -f $ICONV_LANG -t UTF-8
    	    else
                cat -
            fi
    	)
    fi
    ;;
objcheck)
    if [ -e $FULLOBJPATH ]
    then
	echo $STATUS_OK
    else
	echo $STATUS_NO_EXIST
    fi
    ;;
*)
    echo $STATUS_ARGS
esac

) | produceDocument plain

